@@ -19,7 +19,7 @@ class RadicalButton : public QPushButton
 
   public:
              RadicalButton( const QString &text, QWidget *parent );
-    virtual ~RadicalButton();
+    ~RadicalButton() override;
     /**
      * Overriding QPushButton's event for mousewheel events on a disabled button
      */
@@ -36,10 +36,10 @@ class RadicalButton : public QPushButton
       Hidden          /**< Not related (to above), so hide() */
     } ButtonStatus;
 
-  signals:
+  Q_SIGNALS:
     void userClicked( const QString &text, RadicalButton::ButtonStatus status );
 
-  public slots:
+  public Q_SLOTS:
     void mousePressEvent( QMouseEvent *e ) override;
     void mouseReleaseEvent( QMouseEvent *e ) override;
     void resetButton();
